#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-qq
version:              0.8.4
visibility:           public
id:                   aeson-qq-0.8.4-Kk0OWD8LqECIrXNYYWwpai
key:                  aeson-qq-0.8.4-Kk0OWD8LqECIrXNYYWwpai
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  b7e81684481c115e0493f456c2fee194
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-qq-0.8.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-qq-0.8.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-qq-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-qq
hs-libraries:         HSaeson-qq-0.8.4-Kk0OWD8LqECIrXNYYWwpai
depends:
    aeson-2.2.2.0-3wIqYzgVLxh1lGuh6CHfOQ
    attoparsec-0.14.4-FVjluS1LXeOBFikjeFFRQf base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    haskell-src-meta-0.8.15-lsa2AymNiT3KzgvXjohhy parsec-3.1.16.1
    scientific-0.3.8.1-9XG2AQ4sh0vL0ppOZ1hCCJ template-haskell-2.20.0.0
    text-2.0.2 vector-0.13.2.0-5aTe1V6fRGRBDLXlEcUVda

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

